from dataclasses import dataclass

# // Packages Dataclass
@dataclass
class Packages:
    multirow: str = "multirow"
    cancel: str = "cancel"
    changepage: str = "changepage"
    amssymb: str = "amssymb"
    amsmath: str = "amsmath"
    gensymb: str = "gensymb"
    tkzeuclide: str = "tkz-euclide"
    graphicx: str = "graphicx"
